@@ -4,7 +4,6 @@ from django.template.loader import render_to_string
 
 
 class ColorWidget(TextInput):
-
     template_name = "colorfield/color.html"
 
     class Media:
@@ -30,6 +29,8 @@ class ColorWidget(TextInput):
                 "value": value,
             }
         )
+        if "format" not in context:
+            context.update({"format": "hex"})
         return context
 
     def render(self, name, value, attrs=None, renderer=None):
